import rpi_backlight
import tempfile
import pathlib


class Backlight(rpi_backlight.Backlight):
    """
    Wrapper for rpi_backlight.Backlight
    Mocks rpi_backlight.Backlight if run on unsupported platform
    """

    def __init__(self):

        self.fake_path = None

        try:
            super().__init__()
        except FileNotFoundError:

            self.temp_dir = tempfile.TemporaryDirectory()
            self.fake_path = pathlib.Path(self.temp_dir.name)

            files = {"bl_power": 0, "brightness": 255, "max_brightness": 255}

            for filename, value in files.items():
                (self.fake_path / filename).write_text(str(value))

            pathlib.Path(self.fake_path / "actual_brightness").symlink_to(
                self.fake_path / "brightness")

            super().__init__(backlight_sysfs_path=self.fake_path)



import locale
import os

import dotenv

from voicemailbox import app
from voicemailbox import voicemail
from voicemailbox import email

dotenv.load_dotenv()
locale.setlocale(locale.LC_ALL, "")

# Run emails checking
email_manager = email.EmailManager(
    host=os.environ["VOICEMAILBOX_IMAP_SERVER"],
    email_address=os.environ["VOICEMAILBOX_EMAIL_ADDRESS"],
    password=os.environ["VOICEMAILBOX_EMAIL_PASSWORD"],
    dest_path=voicemail.VoicemailManager.PATH_NEW,
    attachment_pattern=voicemail.VoicemailManager.MAIL_PATTERN,
)

email_manager.start()

# Run kivy App
app.VoicemailBoxApp().run()
email_manager.end = True
email_manager.join()



import datetime
import re
import operator
import pathlib


class Voicemail:

    def __init__(self, source):

        if not isinstance(source, pathlib.Path):
            raise ValueError("source must be a Path object")

        self.source = source
        self._read = False

        # filename follows the format
        # « De_[PhoneNumber]_[JJMMAAAA]_[HH]h[MM]_[xxxxxxxxxxxxx].mp3 »
        filename = self.source.name

        day = int(filename.split("_")[2][0:2])
        month = int(filename.split("_")[2][2:4])
        year = int(filename.split("_")[2][4:8])
        hour = int(filename.split("_")[3][0:2])
        minute = int(filename.split("_")[3][3:5])

        self.datetime = datetime.datetime(year=year, month=month, day=day,
                                          hour=hour, minute=minute)
        self.date = self.datetime.date()
        self.time = self.datetime.time()

        self.numero = filename.split("_")[1]

        # Define an attribute for a human readable time and numero
        # The same is done with date (but a property is required)
        self.pretty_time = f"{self.time.hour:02d}h{self.time.minute:02d}"
        self.pretty_numero = (" ".join(re.findall(r"[0-9]{2}", self.numero))
                              if not self.numero == "anonymous"
                              else "numéro inconnu")

    def __eq__(self, other):
        if isinstance(other, Voicemail):
            return self.source == other.source
        else:
            return False

    @property
    def pretty_date(self):
        d = self.datetime
        if d.date() == datetime.date.today():
            return "aujourd’hui"
        elif d.date() == datetime.date.today() - datetime.timedelta(days=1):
            return "hier"
        else:
            return f"{d:%A} {d.day} {d:%B} {d.year}"

    @property
    def read(self):
        return self._read

    @read.setter
    def read(self, value):

        if not isinstance(value, bool):
            raise ValueError("'read' must be a boolean")

        if not self._read == value:
            if value is True:
                VoicemailManager.move_to_read_dir(self)
            else:
                # VMManager.move_to_read_dir()
                pass


class VoicemailManager:

    PATH = pathlib.Path.home() / "Messages vocaux"
    PATH_NEW = PATH / "non lus"
    PATH_READ = PATH / "lus"

    MAIL_PATTERN = re.compile(
        r"^De_([0-9]{10}|anonymous)_"
        r"[0-9]{8}_[0-9]{2}h[0-9]{2}_[0-9a-f]*\.mp3$")

    def __init__(self):

        # Create voicemails directories if they do not exist
        self.PATH_NEW.mkdir(parents=True, exist_ok=True)
        self.PATH_READ.mkdir(parents=True, exist_ok=True)

    @property
    def new_voicemails(self):
        return sorted([Voicemail(file) for file in self.PATH_NEW.iterdir()
                       if self.MAIL_PATTERN.match(file.name)],
                      key=operator.attrgetter("datetime"))

    @classmethod
    def move_to_read_dir(cls, voicemail):
        new_src = voicemail.source.replace(
            cls.PATH_READ / voicemail.source.name)
        voicemail.source = new_src



import time
import threading
import socket
import email
from email import policy

from imapclient import IMAPClient, SocketTimeout
from imapclient.exceptions import IMAPClientAbortError, IMAPClientError

from voicemailbox import logger


class EmailManager(threading.Thread):

    def __init__(self,
                 host="",
                 email_address="",
                 password="",
                 dest_path=None,
                 attachment_pattern=None,
                 ):

        super().__init__()
        self.server_url = host
        self.email_address = email_address
        self.password = password
        self.dest_path = dest_path
        self.attachment_patern = attachment_pattern

        self.server = None
        self.time_start = 0.0

        self.end = False

    def connect(self):

        self.server = IMAPClient(host=self.server_url,
                                 use_uid=True,
                                 timeout=SocketTimeout(connect=15, read=60),
                                 )
        logger.info(f"Connecté au serveur IMAP {self.server_url}")

        self.server.login(self.email_address, self.password)
        logger.info(f"Authentifié sur le serveur "
                    f"en tant que {self.email_address}")

        self.server.select_folder('INBOX')
        logger.info("Boîte « INBOX » sélectionnée")

    def fetch_unseen_emails(self):

        search_result = self.server.search(
            criteria=("UNSEEN",)
        )

        emails = self.server.fetch(search_result, ("BODY[]",))

        # Loops on every found emails
        for uid, e in emails.items():
            logger.info("Traitement d'un nouveau courriel")
            message = email.message_from_bytes(e[b"BODY[]"],
                                               policy=policy.default,
                                               )
            # Loops on every attachment in an email
            for attachment in message.iter_attachments():

                logger.info(f"Pièce jointe de type "
                            f"{attachment.get_content_type()} identifiée")
                filename = attachment.get_filename()
                logger.info(f"Pièce jointe identifiée : {filename}")

                # Download attachment if it matches to the given pattern
                if (self.attachment_patern
                        and self.attachment_patern.match(filename)):
                    with open(self.dest_path / filename, mode="wb") as file:
                        file.write(attachment.get_content())

                    logger.info("La pièce jointe a été enregistrée.")

    def run(self):

        while True:

            try:

                if self.server is None:
                    logger.info(f"Connexion au serveur {self.server_url}")
                    self.connect()
                    self.fetch_unseen_emails()
                    self.time_start = time.monotonic()
                    self.server.idle()
                    logger.info("Passage en mode « idle »")

                # Start IDLE check
                responses = self.server.idle_check(timeout=30)

                if responses:
                    logger.info("Événement reçu du serveur")
                    self.server.idle_done()
                    self.fetch_unseen_emails()
                    self.server.idle()

                if self.end is True:
                    break

                if time.monotonic() - self.time_start >= 200:
                    logger.info("Renouvellement du mode « idle »")
                    self.time_start = time.monotonic()
                    self.server.idle_done()
                    self.server.idle()

            except (socket.gaierror, socket.timeout,
                    IMAPClientAbortError, IMAPClientError,
                    BrokenPipeError) as error:
                logger.warning(error)
                time.sleep(10)
                self.server = None
                continue

            except Exception as error:
                logger.error(f"{type(error)} - {error}")
                time.sleep(600)
                self.server = None
                continue



import kivy.core.audio as kv_audio
import kivy.event as kv_event


class Player(kv_event.EventDispatcher):
    """
    Manager for playing voicemails
    """
    def __init__(self, volume=1.0, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.register_event_type('on_play')
        self.register_event_type('on_stop')
        self.source = None
        self.song = None
        self.duration = None
        self._position = None
        self.manual_paused = False
        self.volume = volume

    def load(self, voicemail):
        self.source = voicemail.source
        self.song = kv_audio.SoundLoader.load(str(self.source))
        self.song.volume = self.volume
        self.duration = self.song.length
        self.position = 0

        # When song is stopped, automatically save current position
        self.song.bind(on_play=lambda x: self.dispatch("on_play"))
        self.song.bind(on_stop=(
            lambda x: self.dispatch("on_stop", end=not self.manual_paused)))

    def save_position(self, *args):
        self.position = self.song.get_pos() if self.song else 0

    def play(self):
        self.manual_paused = False
        self.song.seek(self.position)
        self.song.play()

    def pause(self):
        self.manual_paused = True
        self.song.stop()

    def toggle_play_pause(self):
        if self.song.state == "play":
            self.pause()
        else:
            self.play()

    def unload(self):
        self.song.unload()
        self.song = None

    def on_stop(self, *args, **kwargs):
        self.save_position()

    def on_play(self, *args):
        pass

    @property
    def position(self):
        if self.song is None:
            return None
        elif self.song.state == "play":
            return self.song.get_pos()
        else:
            return self._position

    @position.setter
    def position(self, new_position):
        self._position = new_position

    @property
    def state(self):
        if self.song:
            return self.song.state
        else:
            return "stop"



import datetime

import kivy.uix.screenmanager as kv_screenmanager
import kivy.properties as kv_properties
import kivy.uix.button as kv_button
import kivy.uix.slider as kv_slider
import kivy.clock as kv_clock
import kivy.core.audio as kv_audio

from voicemailbox import logger
from voicemailbox import NEW_MAIL_SONG_PATH
from voicemailbox import voicemail
from voicemailbox import player
from voicemailbox import animation as vmb_animation
from voicemailbox import backlight


class RootScreen(kv_screenmanager.ScreenManager):

    SLEEP_DELAY = 30

    new_voicemails = kv_properties.ListProperty([-1])

    voicemails_volume = (
        kv_properties.BoundedNumericProperty(0.5, min=0.0, max=1.0))
    new_mail_song_volume = (
        kv_properties.BoundedNumericProperty(1.0, min=0.0, max=1.0))

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.vm_manager = voicemail.VoicemailManager()
        self.vm_player = player.Player(volume=self.voicemails_volume)
        self.voicemails_to_play = list()

        # Set brightness to 1 at startup
        self.backlight = backlight.Backlight()
        self.backlight.power = True
        self.backlight.brightness = 100

        self.after_slider_move = ""

        self.ring_song = None
        self.nb_new_voicemails = 0

        # Create sleep and ring events
        self.sleep_event = None
        self.ring_event = None

        # Bind events to callbacks
        self.home_screen \
            .voicemails_button.bind(on_release=self.play_next_voicemail)

        # Loop to bind callbacks to the 2 voice_mail_screen events
        for vms in (self.voicemail_screen_1, self.voicemail_screen_2,):
            vms_slider = vms.voicemail_slider
            vms.play_button.bind(on_release=self.toggle_play_pause)
            vms_slider.bind(is_moving=self.slider_move)

        self.update_new_voicemails()

    def slider_move(self, slider, is_moving):
        """
        If slider is touching down, song is stopped (if necessary)
        after_slider_move attribute is modified
        to adapt performed action when the slider move ends
        (play only if song was playing before the slider move)
        """
        if is_moving:
            if self.vm_player.state == "play":
                self.pause()
                self.after_slider_move = "play"
            else:
                self.after_slider_move = "stop"

        else:
            self.vm_player.position = slider.value
            if self.after_slider_move == "play":
                self.play()

    def update_new_voicemails(self, *args):
        """
        Update list of unread voicemails
        """
        self.new_voicemails = self.vm_manager.new_voicemails

    def update_position(self, vms, *args):
        """
        Update position property according to song position
        only if song is currently playing
        """
        if (self.vm_player.song is not None
                and vms.voicemail_slider.is_moving is False):
            vms.position = self.vm_player.position

    def update_play_button(self, *args, **kwargs):
        self.crt_screen.state = "\uf04c" if (
                self.vm_player.state == "play") else "\uf04b"

    def on_new_voicemails(self, instance, new_voicemails):
        """
        New voicemails list event callback
        Update home screen head label, button and background
        """

        # Check if new voicemails arrived and update new voicemails number
        new_voicemail_arrived = len(new_voicemails) > self.nb_new_voicemails
        self.nb_new_voicemails = len(new_voicemails)

        # These functions return tuples (animation_object, widget)
        # allowing to start animations at the same time
        # animation is enabled if current screen is home screen

        animation = (True if self.current_screen == self.home_screen
                     else False)

        # first item of each tuple is animation_object
        # set to None if animation is disabled
        hl_tuple = self.home_screen \
            .update_head_label(len(new_voicemails), animation=animation)
        btn_tuple = self.home_screen \
            .update_voicemails_button(len(new_voicemails), animation=animation)
        back_tuple = self.home_screen \
            .update_background(len(new_voicemails), animation=animation)

        # Loop for starting animations (if enable)
        for t in (hl_tuple, btn_tuple, back_tuple):
            if t[0] is not None:
                t[0].start(t[1])

        # Wake the backlight up when new voicemails are arriving
        # And ring to alert of these new voicemails
        if new_voicemail_arrived:

            if self.current_screen == self.home_screen:
                self.wake_up()
                self.activate_sleeping()

            self.ring()

    def play_next_voicemail(self, *args):

        if args and isinstance(args[0], kv_button.Button):
            self.voicemails_to_play = self.new_voicemails[:]

        voicemail = self.voicemails_to_play[0]

        # Init VmPlayer and load voicemail
        self.vm_player.load(voicemail)
        self.vm_player.bind(on_play=self.update_play_button)
        self.vm_player.bind(on_stop=self.manage_mail_stop)

        # Update voicemail screen information
        self.next_voicemail_screen.voicemail = voicemail
        self.next_voicemail_screen.duration = self.vm_player.duration

        # Display voicemail_screen and play voicemail
        self.crt_screen = self.next_voicemail_screen
        self.vm_player.play()
        logger.info(f"Volume VmPlayer : {self.vm_player.song.volume}")

    def toggle_play_pause(self, *args):
        self.vm_player.toggle_play_pause()

    def pause(self, *args):
        self.vm_player.pause()

    def play(self, *args):
        self.vm_player.play()

    def manage_mail_stop(self, *args, **kwargs):
        # Update play button and go to next screen if mail is ended
        self.update_play_button()
        if kwargs.get("end", False):
            self.to_next_screen()

    def to_next_screen(self):

        # check if current screen is a voicemail_screen (1 or 2)
        # if it is, unload voicemail, update voicemails_to_play list,
        # marks current mail as read and update new_voicemails list
        # (for home screen to be up to date)
        if self.crt_screen in (self.voicemail_screen_1,
                               self.voicemail_screen_2):

            self.vm_player.unload()
            self.voicemails_to_play.remove(self.crt_screen.voicemail)
            self.crt_screen.voicemail.read = True
            self.new_voicemails = self.vm_manager.new_voicemails

            if self.voicemails_to_play:
                self.play_next_voicemail()
            else:
                self.crt_screen = self.home_screen

    def sleep(self, *args):
        if self.current_screen == self.home_screen:
            with self.backlight.fade(duration=1):
                self.backlight.brightness = 0
            self.backlight.power = False

    def wake_up(self):
        self.backlight.power = True
        with self.backlight.fade(duration=1):
            self.backlight.brightness = 100

    def deactivate_sleeping(self):
        if getattr(self, "sleep_event", None) is not None:
            self.sleep_event.cancel()
            logger.info("deactivate sleeping !")
        else:
            logger.info("cannot deactivate, sleep_event is None")

    def activate_sleeping(self):
        self.deactivate_sleeping()
        self.sleep_event = kv_clock.Clock.schedule_once(self.sleep,
                                                        self.SLEEP_DELAY)
        logger.info("activate sleeping !")

    def ring(self, *args):
        logger.info("RING !")
        if getattr(self, "ring_event", None) is not None:
            logger.info("ring_event is not None")
            self.ring_event.cancel()

        # Load new mail song
        self.ring_song = kv_audio.SoundLoader.load(str(NEW_MAIL_SONG_PATH))
        self.ring_song.volume = self.new_mail_song_volume
        self.ring_song.bind(on_stop=lambda x: self.ring_song.unload())

        # Ring only on home screen and if there are still new voicemails
        if self.current_screen == self.home_screen and self.new_voicemails:
            self.ring_song.seek(0)
            self.ring_song.play()

        # If there are still new voicemails, schedule a new ring
        # a minute later
        if self.new_voicemails:
            self.ring_event = kv_clock.Clock.schedule_once(self.ring, 60)

    def on_touch_up(self, touch):
        do_not_propagate = False
        if not self.backlight.power:
            self.wake_up()
            do_not_propagate = True

        if self.current_screen == self.home_screen:
            self.activate_sleeping()

        return do_not_propagate

    @property
    def crt_screen(self):
        return getattr(self, self.current, None)

    @crt_screen.setter
    def crt_screen(self, screen):
        if screen == self.home_screen:
            self.current = "home_screen"
        elif screen == self.voicemail_screen_1:
            self.current = "voicemail_screen_1"
        elif screen == self.voicemail_screen_2:
            self.current = "voicemail_screen_2"
        else:
            raise ValueError("unknown screen")

    @property
    def next_voicemail_screen(self):
        if self.crt_screen == self.home_screen:
            return self.voicemail_screen_1
        elif self.crt_screen == self.voicemail_screen_1:
            return self.voicemail_screen_2
        elif self.crt_screen == self.voicemail_screen_2:
            return self.voicemail_screen_1
        else:
            return None

class HomeScreen(kv_screenmanager.Screen):
    background_rgba = kv_properties.ListProperty([0 / 255,
                                                  0 / 255,
                                                  0 / 255, 1]
                                                 )
    head_label = kv_properties.ObjectProperty(None)
    home_screen_background = kv_properties.ObjectProperty(None)

    current_date = kv_properties.StringProperty("")
    current_time = kv_properties.StringProperty("")

    def on_enter(self):
        root_screen = self.parent
        root_screen.activate_sleeping()

    def update_background(self, nb_new_voicemails, animation=True):
        """
        Background transition
        (no voicemail : blue/green ; new voicemails : red)
        :param nb_new_voicemails: int
        :param animation: bool
        :return: (VMAnimation object, widget)
        """
        background_color = None

        if nb_new_voicemails:
            background_color = (217 / 255, 33 / 255, 33 / 255, 1)
        else:
            background_color = (1 / 255, 120 / 255, 111 / 255, 1)

        if background_color != self.background_rgba:
            if animation:
                return (vmb_animation.Animation.background_fade(
                    self, background_color),
                        self,
                        )
            else:
                self.background_rgba = background_color
                return None, self

    def update_head_label(self, nb_new_voicemails, animation=True):
        """
        Head label transition (Pas de nouveau message ; X nouveaux messages)
        :param nb_new_voicemails: int
        :param animation: bool
        :return: (VMAnimation object, widget)
        """
        if nb_new_voicemails > 1:
            head_label = f"{nb_new_voicemails} nouveaux messages"
        elif nb_new_voicemails == 1:
            head_label = f"{nb_new_voicemails} nouveau message"
        else:
            head_label = f"Pas de nouveau message"

        if animation:
            return (vmb_animation.Animation.fade_out_in(self.head_label,
                                                        "text",
                                                        head_label),
                    self.head_label
                    )
        else:
            self.head_label.text = head_label
            return None, self.head_label

    def update_voicemails_button(self, nb_new_voicemails, animation=True):
        """
        Home screen button transition
        (no voicemail : no button ; new voicemails : button)
        :param nb_new_voicemails: int
        :param animation: bool
        :return: (VMAnimation object, widget)
        """
        if nb_new_voicemails:
            if animation:
                return (vmb_animation.Animation.fade_in(
                    self.voicemails_button),
                        self.voicemails_button)
            else:
                self.voicemails_button.disabled = False
                self.voicemails_button.opacity = 1
                return None, self.voicemails_button
        else:
            if animation:
                return (vmb_animation.Animation.fade_out(
                    self.voicemails_button),
                        self.voicemails_button)
            else:
                self.voicemails_button.disabled = True
                self.voicemails_button.opacity = 0
                return None, self.voicemails_button

    def update_datetime(self, *args):

        dt = datetime.datetime.now()

        self.current_date = dt.strftime("%A %d %B %Y")
        self.current_time = dt.strftime("%Hh%M")


class VoicemailScreenCore(kv_screenmanager.Screen):
    voicemail = kv_properties.ObjectProperty(None, allownone=True)

    position = kv_properties.NumericProperty(0)
    duration = kv_properties.NumericProperty(0)
    state = kv_properties.StringProperty("\uf04c")
    date = kv_properties.StringProperty("")
    time = kv_properties.StringProperty("")
    numero = kv_properties.StringProperty("")
    label = kv_properties.StringProperty("")

    def __init__(self, **kwargs):
        super(VoicemailScreenCore, self).__init__(**kwargs)

    def on_enter(self):
        logger.info(f"Enter Voicemail screen, parent : {self.parent}")
        root_screen = self.parent
        root_screen.deactivate_sleeping()

    def on_voicemail(self, instance, voicemail):
        self.date = voicemail.pretty_date
        self.time = voicemail.pretty_time
        self.numero = voicemail.pretty_numero

        self.label = f"Message reçu\n" \
                     f"[b]{self.date}[/b] à [b]{self.time}[/b]\n" \
                     f"{'du ' if not self.numero[0] == 'n' else ''}" \
                     f"[b]{self.numero}[/b]"


class VoicemailScreen1(VoicemailScreenCore):
    pass


class VoicemailScreen2(VoicemailScreenCore):
    pass


class VoicemailSlider(kv_slider.Slider):
    """
    Slider shown in voicemail screen
    """

    is_moving = kv_properties.BooleanProperty(False)

    def on_touch_down(self, touch):
        """
        When slider is touched down,
        is_moving set to True
        """

        if self.collide_point(*touch.pos):
            self.is_moving = True
            touch.grab(self)

        super().on_touch_down(touch)

    def on_touch_up(self, touch):
        """
        When slider is touched up,
        is_moving set to False
        """

        if touch.grab_current is self and self.is_moving:
            self.is_moving = False
            touch.ungrab(self)
            return True

        else:
            super().on_touch_up(touch)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['voicemailbox']

package_data = \
{'': ['*'],
 'voicemailbox': ['static/fonts/*', 'static/images/*', 'static/songs/*']}

install_requires = \
['IMAPClient>=2.2.0,<3.0.0',
 'PyYAML>=5.4.1,<6.0.0',
 'kivy>=2.0.0,<3.0.0',
 'python-dotenv>=0.15.0,<0.16.0',
 'rpi-backlight>=2.2.0,<3.0.0']

setup_kwargs = {
    'name': 'voicemailbox',
    'version': '0.1.5',
    'description': 'Application for reading voice messages',
    'long_description': '# VoicemailBox\n\nVoicemailBox is an application for reading voice messages left on a fixed \ntelephone line.\n\nIts graphical interface is based on the Kivy framework.\n\nCreated to run on a Raspberry Pi with a touch screen, \nit should work on any GNU/Linux system.\n\n# Purpose\n\nIn France, some operators offer, as an option, to send voice messages left \non a fixed line to a given email address.\n\nVoicemailBox retrieves the voicemail messages thus sent, signals their arrival \nand offers a graphical interface to read them.\n\nFor now, it is designed to work with the French operator Bouygues Telecom.\n\n## Installation - General case\n\nVoicemailBox can be installed with pip :\n```bash\npip install voicemailbox\n```\n\n## Installation - Raspberry Pi\n\nThe app has been tested on a Raspberry Pi 3, running Raspberry Pi OS Lite \n(Buster release), and the following hardware :\n- official Raspberry Pi touchscreen ;\n- OneNiceDesign touchscreen case ;  \n- adafruit speaker bonnet ;\n- adafruit stereo enclosed speaker set.\n\nOn this system, some packages have to be installed first \n([Source](https://kivy.org/doc/stable/installation/installation-rpi.html)) :\n```bash\napt install libsdl2-dev libsdl2-image-dev libsdl2-mixer-dev \\ \nlibsdl2-ttf-dev pkg-config libgl1-mesa-dev libgles2-mesa-dev \\\npython3-setuptools python3-dev libmtdev-dev \\ \nxclip xsel libjpeg-dev ffmpeg\n```\n\nThen, Kivy and VoicemailBox can be installed \n(virtual environment recommended) :\n```bash\npip install --upgrade pip setuptools Cython\npip install kivy[base,media] --no-binary kivy\npip install voicemailbox\n```\n\nTo allow `rpi-backlight` to manage touchscreen backlight without root access,\na udev rule has to be created :\n```bash\n$ echo \'SUBSYSTEM=="backlight",RUN+="/bin/chmod 666 /sys/class/backlight/%k/brightness /sys/class/backlight/%k/bl_power"\' | sudo tee -a /etc/udev/rules.d/backlight-permissions.rules\n```\n\n### Additionnal configuration\n\nThe following instructions enable VoicemailBox to be integrated \nwith the hardware described above :\n\n\n- edit  `/boot/config.txt` :\n\t- touchscreen rotation : add `lcd_rotate=2`\t\n\t- GPU\'s memory set to 256 Mb : add `gpu_mem=256`\n\t- adafruit speaker bonnet :\n\t\t- add `dtoverlay=hifiberry-dac`\n\t\t- add `dtoverlay=i2s-mmap`\n\t\t- comment `dtparam=audio=on`\n\t\n\n- for speaker bonnet support, create `/etc/asound.conf` with the following content :\n\t```bash\n\tpcm.speakerbonnet {\n\t   type hw card 0\n\t}\n\n\tpcm.dmixer {\n\t   type dmix\n\t   ipc_key 1024\n\t   ipc_perm 0666\n\t   slave {\n\t     pcm "speakerbonnet"\n\t     period_time 0\n\t     period_size 1024\n\t     buffer_size 8192\n\t     rate 44100\n\t     channels 2\n\t   }\n\t}\n\n\tctl.dmixer {\n\t    type hw card 0\n\t}\n\n\tpcm.softvol {\n\t    type softvol\n\t    slave.pcm "dmixer"\n\t    control.name "PCM"\n\t    control.card 0\n\t}\n\n\tctl.softvol {\n\t    type hw card 0\n\t}\n\n\tpcm.!default {\n\t    type             plug\n\t    slave.pcm       "softvol"\n\t}\t   \n\t```\n\n\n- Wi-Fi : create wpa_supplicant.conf file in `/boot` with following content \n  ([Source](https://www.raspberrypi.org/documentation/configuration/wireless/headless.md)) :\n\t```bash\n\tctrl_interface=DIR=/var/run/wpa_supplicant GROUP=netdev\n\tupdate_config=1\n\tcountry=<Insert 2 letter ISO 3166-1 country code here>\n\t\n\tnetwork={\n\t ssid="<Name of your wireless LAN>"\n\t psk="<Password for your wireless LAN>"\n\t}\n\t```\n\n\n- to use kivy with Raspberry Pi touchscreen, modify `~/.kivy/config.ini`, \n  add under `[input]` section :\n\t```bash\n\tmouse = mouse\n\tmtdev_%(name)s = probesysfs,provider=mtdev\n\thid_%(name)s = probesysfs,provider=hidinput\n\t```\n\n- create systemd service to run at startup :\n  \n\t- create `/etc/systemd/system/voicemailbox.service` \n\t  with the follonwing content :\n\t\t```bash\n\t\t[Unit]\n\t\tDescription=voicemailbox\n\t\tAfter=multi-user.target\n\t\t\n\t\t[Service]\n\t\tType=idle\n\t\tEnvironment=KIVY_AUDIO=ffpyplayer\n\t\tExecStart=/home/pi/.venv/bin/python -m voicemailbox\n\t\tWorkingDirectory=/home/pi/\n\t\tUser=pi\n\t\t\n\t\t[Install]\n\t\tWantedBy=multi-user.target\n\t\t```\n\t\n\t- run at start-up :\n\t  ```bash\n\t  sudo systemctl enable voicemailbox\n      ```\n\n- use [Log2Ram](https://github.com/azlux/log2ram) :\n\t- install :\n\t\t```bash\n\t\techo "deb http://packages.azlux.fr/debian/ buster main" | sudo tee /etc/apt/sources.list.d/azlux.list\n\t\twget -qO - https://azlux.fr/repo.gpg.key | sudo apt-key add -\n\t\tapt update\n\t\tapt install log2ram\n\t\t```\n\t- modify frequency : run `systemctl edit log2ram-daily.timer` and add :\n\t\t```bash\n\t\t[Timer]\n\t\tOnCalendar=weekly\n\t\t```\n\n## Usage\n\nSome environment variables have to be defined before running the application :\n```bash\nVOICEMAILBOX_IMAP_SERVER # IMAP server address\nVOICEMAILBOX_EMAIL_ADDRESS # User email address\nVOICEMAILBOX_EMAIL_PASSWORD # User password\n```\n\nThen VoicemailBox can be launched :\n```bash\npython -m voicemailbox\n```\n\n## Third party libraries and dependencies\n\nVoicemailBox makes use of the following third party projects :\n- [Kivy](https://kivy.org) (MIT license) ;\n- [IMAPClient](https://imapclient.readthedocs.io) (New BSD license) ;\n- [rpi_backlight](https://github.com/linusg/rpi-backlight) (MIT license) ;\n- [python_dotenv](https://saurabh-kumar.com/python-dotenv) (BSD license) ;\n- [PYYaml](https://pyyaml.org) (MIT license).\n\n\nVoicemailBox also includes :\n- the [FontAwesome](https://fontawesome.com/) icons (SIL Open Font License) ;\n- the ring song from \n  [LaSonotheque.org](https://lasonotheque.org/detail-0292-clochette-1.html)\n  (Free license).\n\n\n## License\n\nVoicemailBox is placed under \n[CeCILL license](http://cecill.info/licences/Licence_CeCILL_V2.1-en.html) \n(version 2.1).',
    'author': 'Pierre Gobin',
    'author_email': 'dev@pierregobin.fr',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



import logging.config
from pathlib import Path
import yaml


class Logging:

    def __init__(self):
        with open(Path(__file__).parent / "logging.conf", mode="r") as f:
            logging.config.dictConfig(yaml.load(f, Loader=yaml.FullLoader))
        self.logger = logging.getLogger("voicemailbox")
